@@ -15,7 +15,7 @@ import re
 
 
 logger = logging.getLogger(__name__)
-gist_regex = re.compile(r'(<p>\[gist:id\=([0-9]+),file\=([^\]]+)\]</p>)')
+gist_regex = re.compile(r'(<p>\[gist:id\=([0-9a-fA-F]+)(,file\=([^\]]+))?\]</p>)')
 gist_template = """<div class="gist">
     <script src='{{script_url}}'></script>
     <noscript>
@@ -28,22 +28,29 @@ def html_output(script_url, code):
     return ""
 
 
-def gist_url(gist_id, filename):
-    return "https://raw.github.com/gist/{}/{}".format(gist_id, filename)
+def gist_url(gist_id, filename=None):
+    url = "https://raw.github.com/gist/{}".format(gist_id)
+    if filename is not None:
+        url += "/{}".format(filename)
+    return url
 
 
-def script_url(gist_id, filename):
-    return "https://gist.github.com/{}.js?file={}".format(gist_id, filename)
+def script_url(gist_id, filename=None):
+    url = "https://gist.github.com/{}.js".format(gist_id)
+    if filename is not None:
+        url += "?file={}".format(filename)
+    return url
 
 
-def cache_filename(base, gist_id, filename):
+def cache_filename(base, gist_id, filename=None):
     h = hashlib.md5()
     h.update(gist_id)
-    h.update(filename)
+    if filename is not None:
+        h.update(filename)
     return os.path.join(base, '{}.cache'.format(h.hexdigest()))
 
 
-def get_cache(base, gist_id, filename):
+def get_cache(base, gist_id, filename=None):
     cache_file = cache_filename(base, gist_id, filename)
     if not os.path.exists(cache_file):
         return None
@@ -51,12 +58,12 @@ def get_cache(base, gist_id, filename):
         return f.read()
 
 
-def set_cache(base, gist_id, filename, body):
+def set_cache(base, gist_id, body, filename=None):
     with open(cache_filename(base, gist_id, filename), 'w') as f:
         f.write(body)
 
 
-def fetch_gist(gist_id, filename):
+def fetch_gist(gist_id, filename=None):
     """Fetch a gist and return the raw contents."""
     import requests
 
@@ -96,7 +103,9 @@ def replace_gist_tags(generator):
     for article in generator.articles:
         for match in gist_regex.findall(article._content):
             gist_id = match[1]
-            filename = match[2]
+            filename = None
+            if match[3]:
+                filename = match[3]
             logger.info('[gist]: Found gist id {} and filename {}'.format(
                 gist_id,
                 filename
@@ -112,15 +121,15 @@ def replace_gist_tags(generator):
 
                 if should_cache:
                     logger.info('[gist]:   Saving gist to cache...')
-                    set_cache(cache_location, gist_id, filename, body)
+                    set_cache(cache_location, gist_id, body, filename)
             else:
                 logger.info('[gist]:   Found gist in cache.')
 
             # Create a context to render with
             context = generator.context.copy()
             context.update({
-                'script_url': script_url(gist_id, filename),
-                'code': body,
+                'script_url': unicode(script_url(gist_id, filename), 'utf-8'),
+                'code': unicode(body, 'utf-8'),
             })
 
             # Render the template
